from pgm import render, log
from pgm.timing import controller, modifier, keyframe
from pgm.layout import window, group
from pgm.form import rectangle, stroke, color
import sys, time, pgmrender, gobject

render.init('opengl1')
#log.set_level(log.DEBUG)

rect = None
ctrl = None
win = None
fs = True

def key_press_cb(event):
    if event.keyval == pgmrender.KEY_ESCAPE:
        win.set_fullscreen(False)
        win.main_quit()
    elif event.keyval == pgmrender.KEY_w:
        win.cursor = 2
    elif event.keyval == pgmrender.KEY_x:
        win.cursor = 1
    elif event.keyval == pgmrender.KEY_q:
        ctrl.stop()
    elif event.keyval == pgmrender.KEY_s:
        ctrl.start()
    elif event.keyval == pgmrender.KEY_f:
        global fs
        fs = not fs
        win.set_fullscreen(fs, (800, 600))

def main(args):
    global ctrl, win, rect
    # The Window
    win = window.Window(title='Timed animation', size=(1280,1024),
                        fullscreen=True)

    # A blue RoundedRectangle with a white continuous stroke
    fill = color.Color((255, 100, 50, 255))
    rect = rectangle.RoundRectangle(size=(200,100), position=(100,100),
                                    paint=fill, stroke=stroke.Stroke(width=2.0))
    #rect.arc = (25, 25)

    # Put the rectangle in the window
    win.add(rect)

    # Signal connections
    win.sig_exit_event.connect(lambda _: sys.exit(0))
    win.sig_key_press_event.connect(key_press_cb)

    # Animations
    timeline_rot = [keyframe.KeyFrame((0,0,0), 0.0),
                    keyframe.KeyFrame((0,180,0), 0.25),
                    keyframe.KeyFrame((180,180,0), 0.5),
                    keyframe.KeyFrame((180,360,0), 0.75),
                    keyframe.KeyFrame((0,360,0), 1.0)]
    mdf_rot = modifier.Modifier([rect], 'rotation', timeline_rot)

    timeline_pos = [keyframe.KeyFrame((100,100), 0.0),
                    keyframe.KeyFrame((500,100), 0.25),
                    keyframe.KeyFrame((500,400), 0.5),
                    keyframe.KeyFrame((100,400), 0.75),
                    keyframe.KeyFrame((100,100), 1.0)]
    mdf_pos = modifier.Modifier([rect], 'position', timeline_pos)

    ctrl = controller.Controller(begin=0, duration=3000, resolution=10,
                                 repeat_behavior=controller.REVERSE,
                                 repeat_count=2, end_behavior=controller.BEGIN,
                                 modifiers=[mdf_rot, mdf_pos],
                                 interpolation=controller.SINUSOIDAL)

    # Start the loop
    gobject.timeout_add(25, win.update)
    win.main()

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
